@@ -359,7 +359,7 @@ class Client:
             raise HTTPResponseError(error.response)
         return response.json()
 
-    def download_file(self, url, page):
+    def download_file(self, url, page, block_id):
         """
         Download a file from a given URL into the MEDIA_ROOT.
 
@@ -369,12 +369,12 @@ class Client:
         url_path = path.basename(urlparse(url).path)
         _, extension = path.splitext(url_path)
         request_stream = requests.get(url, stream=True)
-        return self.save_file(request_stream.content, page, extension)
+        return self.save_file(request_stream.content, page, extension, block_id)
 
-    def save_file(self, content, page, extension):
-        page_id_chars = strip_hyphens(page.notion_id)
+    def save_file(self, content, page, extension, block_id):
+        block_id_chars = strip_hyphens(block_id)
         page_title = sanitize_filename(page.title.to_plain_text())
-        relative_filepath = f"{page_title}-{page_id_chars[:11]}{extension}"
+        relative_filepath = f"{page_title}-{block_id_chars[:11]}{extension}"
         full_filepath = path.join(self.media_root, relative_filepath)
         makedirs(self.media_root, exist_ok=True)
         with open(full_filepath, 'wb') as temp_file:
@@ -385,19 +385,20 @@ class Client:
         '''
         copy the notion children (`children`) of one notion database to another (`destination`)
         '''
+        bad_keys = [
+            'id',
+            'url',
+            'parent',
+            'created_by',
+            'created_time',
+            'last_edited_by',
+            'last_edited_time',
+        ]
         db_children = [
             {
                 key: value
                 for (key, value) in child.items()
-                if key not in [
-                    'id',
-                    'url',
-                    'parent',
-                    'created_by',
-                    'created_time',
-                    'last_edited_by',
-                    'last_edited_time',
-                ]
+                if key not in bad_keys
             } for child in children
         ]
         for page in db_children:
@@ -406,14 +407,16 @@ class Client:
                 'database_id': destination['id']
             }
             for key in page['properties'].keys():
-                del page['properties'][key]['id']
-                prop_type = page['properties'][key]['type']
-                del page['properties'][key]['type']
-                prop_type_info = page['properties'][key][prop_type]
+                prop = page['properties'][key]
+                del prop['id']
+                prop_type = prop['type']
+                del prop['type']
+                prop_type_info = prop[prop_type]
                 if isinstance(prop_type_info, dict):
-                    del page['properties'][key][prop_type]['id']
+                    if 'id' in prop_type_info:
+                        del prop_type_info['id']
                 elif isinstance(prop_type_info, list) and prop_type != 'relation':
-                    for item in page['properties'][key][prop_type]:
+                    for item in prop_type_info:
                         if 'id' in item:
                             del item['id']
             self.create_notion_page(page)
@@ -452,6 +455,12 @@ class Client:
         object_is_database = lambda child: child['object'] == 'database'
         type_is_page = lambda child: 'type' in child and child['type'] == 'child_page'
         object_is_page = lambda child: child['object'] == 'page'
+        bad_keys = [
+            'last_edited_by',
+            'created_time',
+            'last_edited_time',
+            'created_by'
+        ]
         for i, child in enumerate(children):
             if object_is_database(child) or type_is_database(child):
                 children_appended = append_blocks(last_i, i, children, children_appended)
@@ -467,12 +476,7 @@ class Client:
                         key: value
                         for (key, value) in
                         database.notion_data.items()
-                        if key not in [
-                            'last_edited_by',
-                            'created_time',
-                            'last_edited_time',
-                            'created_by'
-                        ]
+                        if key not in bad_keys
                     }
                     child['parent'] = {
                         'type': f'{parent_type}_id',
@@ -498,12 +502,7 @@ class Client:
                         key: value
                         for (key, value) in
                         page.notion_data.items()
-                        if key not in [
-                            'last_edited_by',
-                            'created_time',
-                            'last_edited_time',
-                            'created_by'
-                        ]
+                        if key not in bad_keys
                     }
                     child['parent'] = {
                         'type': f'{parent_type}_id',
